
local GreatLadder = ...

-- Register great ladder prefab nodes
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/step_0_RootPart", "GREAT_LADDER_2_ROOT_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/step_3_TopPart", "GREAT_LADDER_2_TOP_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/step_2_Tiling2Part", "GREAT_LADDER_2_TILING2_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/step_1_Tiling3Part", "GREAT_LADDER_2_TILING3_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/StartPart", "GL2_BRIDGE_START_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/EndPart", "GL2_BRIDGE_END_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/StartSlopePart", "GL2_BRIDGE_SLOPE_START_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/EndSlopePart", "GL2_BRIDGE_SLOPE_END_PREFAB")
GreatLadder:registerAssetId("models/greatLadder2.fbx/Prefab/greatLadder/TilingPart", "GL2_BRIDGE_TILING_PREFAB")
--------------------------------------------------------------------------

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	GreatLadder:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = { DataType = "BUILDING_CONSTRUCTOR_DEFAULT", CoreObjectPrefab = _nodePrefix .. "_PREFAB" }
	})
end

local defaultNodePrefixList = {
	"GREAT_LADDER_2_TOP",
	"GREAT_LADDER_2_TILING2",
	"GREAT_LADDER_2_TILING3"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

--------------------------------------------------------------------------

-- Register the great ladder part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GREAT_LADDER_2_ROOT_PART",
	Name = "GREAT_LADDER_2_NAME",
	Description = "GREAT_LADDER_2_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "GREAT_LADDER_2_ROOT_PREFAB",
		EndPart = "GREAT_LADDER_2_TOP_PART",
		FillerList = {
			"GREAT_LADDER_2_TILING2_PART"
                },
		BasementFillerList = {
			"GREAT_LADDER_2_TILING3_PART"
         	},
		MinimumScale = 12,
		BasementScale = 1
--,
--		IsVertical = true
	},
--Les ressources ncessaires.
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
})
-- Register bridge tiling (the pillar part that extends to the ground)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL2_BRIDGE_TILING_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "GL2_BRIDGE_TILING_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 2 }
		}
	},
})


-- Register bridge start part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL2_BRIDGE_START_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL2_BRIDGE_START_PREFAB",
		FillerList = {
			"GL2_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 5 }
		},
	},
})

-- Register bridge end part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL2_BRIDGE_END_PART",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL2_BRIDGE_END_PREFAB",
		FillerList = {
			"GL2_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 5 }
		},
	},
})

-- Register bridge start slope part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL2_BRIDGE_SLOPE_START_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL2_BRIDGE_SLOPE_START_PREFAB",
		FillerList = {
			"GL2_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 2 }
		},
	},
})

-- Register bridge end slope part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL2_BRIDGE_SLOPE_END_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL2_BRIDGE_SLOPE_END_PREFAB",
		FillerList = {
			"GL2_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 2 }
		},
	},
})

-- Register the core part (the part with the bridge mover)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL2_BRIDGE_CORE_PART",
	Name = "GL2_BRIDGE_CORE_NAME",
	Description = "GL2_BRIDGE_CORE_DESC",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = "GL2_BRIDGE_START_PART",
		EndPart = "GL2_BRIDGE_END_PART",
		FillerList = {
			"GREAT_LADDER_2_ROOT_PART"
		},
		SlopeFillerList = {
			"GL2_BRIDGE_SLOPE_END_PART"
		},
		SlopeStartFillerList = {
			"GL2_BRIDGE_SLOPE_START_PART"
		},
		MinimumScale = 1,
	},
	BuildingFunction = {
		DataType = "BUILDING_FUNCTION_BRIDGE"
	}
})

GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/step_0_RootPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/step_3_TopPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/step_2_Tiling2Part", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/step_1_Tiling3Part", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/StartPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/EndPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/StartSlopePart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder2.fbx/Prefab/greatLadder/EndSlopePart", { "BRIDGE" })
-- Register grounding components

GreatLadder:registerPrefabComponent("models/greatLadder2.fbx/Prefab/greatLadder/step_0_RootPart", {
	DataType = "COMP_GROUNDED"
})

-- Override building part components properties (generated by the building asset processor) to add building zones

GreatLadder:registerPrefabComponent("models/greatLadder2.fbx/Prefab/greatLadder/step_0_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 1, 1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder2.fbx/Prefab/greatLadder/StartPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
GreatLadder:registerPrefabComponent("models/greatLadder2.fbx/Prefab/greatLadder/EndPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
GreatLadder:registerPrefabComponent("models/greatLadder2.fbx/Prefab/greatLadder/StartSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
GreatLadder:registerPrefabComponent("models/greatLadder2.fbx/Prefab/greatLadder/EndSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 2 }
})
