
local GreatLadder = ...

-- Register great ladder prefab nodes
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", "GL3_BRIDGE_CENTER_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/RootPart", "GL3_BRIDGE_CENTER_ROOT_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", "GL3_BRIDGE_START_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", "GL3_BRIDGE_END_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", "GL3_BRIDGE_SLOPE_START_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", "GL3_BRIDGE_SLOPE_END_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/TilingPart", "GL3_BRIDGE_TILING_PREFAB")
--------------------------------------------------------------------------

--------------------------------------------------------------------------
-- Register bridge tiling (the pillar part that extends to the ground)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_TILING_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "GL3_BRIDGE_TILING_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	},
})


-- Register bridge start part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_START_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL3_BRIDGE_START_PREFAB",
		FillerList = {
			"GL3_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		},
	},
})

-- Register bridge end part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_END_PART",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL3_BRIDGE_END_PREFAB",
		FillerList = {
			"GL3_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		},
	},
})

-- Register bridge start slope part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_SLOPE_START_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL3_BRIDGE_SLOPE_START_PREFAB",
		FillerList = {
			"GL3_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		},
	},
})

-- Register bridge end slope part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_SLOPE_END_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = "GL3_BRIDGE_SLOPE_END_PREFAB",
		FillerList = {
			"GL3_BRIDGE_TILING_PART"
		},
		BasementScale = 1,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		},
	},
})

-- Register bridge center top part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_CENTER_TOP_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "GL3_BRIDGE_CENTER_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		},
	},
})

-- Register the center root part (the scalable part that places multiple center top parts)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_CENTER_CORE_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = "GL3_BRIDGE_CENTER_ROOT_PREFAB",
		EndPart = "GL3_BRIDGE_CENTER_TOP_PART",
		FillerList = {
			"GL3_BRIDGE_TILING_PART"
		},
		BasementScale = 2,
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		},
	},
})

-- Register the core part (the part with the bridge mover)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = "GL3_BRIDGE_CORE_PART",
	Name = "GL3_BRIDGE_CORE_NAME",
	Description = "GL3_BRIDGE_CORE_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = "GL3_BRIDGE_START_PART",
		EndPart = "GL3_BRIDGE_END_PART",
		FillerList = {
			"GL3_BRIDGE_CENTER_CORE_PART"
		},
		SlopeFillerList = {
			"GL3_BRIDGE_SLOPE_END_PART"
		},
		SlopeStartFillerList = {
			"GL3_BRIDGE_SLOPE_START_PART"
		},
		MinimumScale = 0,
	},
	BuildingFunction = {
		DataType = "BUILDING_FUNCTION_BRIDGE"
	}
})

GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", { "BRIDGE" })

-- Override building part components properties (generated by the building asset processor) to add building zones

GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
